--[[=============================================================================
    Generic Proxy Class

    Copyright 2015 Control4 Corporation. All Rights Reserved.
===============================================================================]]

-- This macro is utilized to identify the version string of the driver template version used.
if (TEMPLATE_VERSION ~= nil) then
	TEMPLATE_VERSION.generic_proxy_class = "2015.10.21"
end

GenericProxy = inheritsFrom(nil)

function GenericProxy:construct(bindingID, maxLevel)
	-- member variables
	self._BindingID = bindingID
	self._MaxLevel = maxLevel

	self:Initialize()

	if PersistData == nil then
		PersistData = {}
	end

	-- setup any data that needs to be persisted
	if PersistData.genericData == nil then
		PersistData.genericData = {}
	end

	self._GenericData = PersistData.genericData	

end

function GenericProxy:Initialize()
	-- create and initialize member variables
	self._Level = 0
	
end

--[[=============================================================================
    Generic Proxy Commands(PRX_CMD)
===============================================================================]]
function GenericProxy:prx_GET_STATE()
	GET_STATE()
end

function GenericProxy:prx_SET_LEVEL(tParams)
	local level = tParams["LEVEL"]

	if (level ~= nil and level ~= self._Level) then
		SET_LEVEL(level)
	end
end


--[[=============================================================================
    Generic Proxy UIRequests
===============================================================================]]
function GenericProxy:req_GET_MAX_LEVEL()
	return self._MaxLevel
end

--[[=============================================================================
    Generic Proxy Notifies
===============================================================================]]
function GenericProxy:dev_Level(level)
	if (self._Level ~= level) then
		self._Level = level
	
		-- send notification that level has changed
		NOTIFY.LEVEL_CHANGED(self._BindingID, self._Level)
	end
end


--[[=============================================================================
    Generic Proxy Functions
===============================================================================]]
-- Create class functions required by the class
function GenericProxy:GetLevel()
	return self._Level
end

